
create tablespace ecare 
datafile '/u00/dbs/databases/CNS/ecare.dbf' size 5M
default storage (initial 2M next 500K  pctincrease 0);

#temporary tbs
create tablespace etemp 
datafile '/u00/dbs/databases/CNS/etemp.dbf' size 1M
default storage (initial 400K next 200K  pctincrease 0);

#roll back segment
create tablespace ecare_rbs 
datafile '/u00/dbs/databases/CNS/ecare_rbs.dbf' size 2M
default storage (initial 500K next 500K  pctincrease 0);

#index tbs
create tablespace ecare_index 
datafile '/u00/dbs/databases/CNS/ecare_index.dbf' size 2M
default storage (initial 500K next 500K  pctincrease 0);

