create table billinfo 
 	(mobil_tn 	char(10) 
			constraint nn_mobtn not null
			constraint pk_tn primary key,
	mobil_pin	char (4)
			constraint nn_mobpin not null,
	last_bill_date	date,
	amount_due	varchar2(5),	
	min_used	number(2),
	min_left	number(2)),
	ip_addr		varchar2(80),
	card_type	varchar2(10),
	card_num	varchar2(20),
	exp_date	date
	tablespace ecare;

 

